==> jmb.fax-0.2.tar.gz: jmb.fax-0.2/jmb/fax/kpn/__init__.py <==
"""
Module to parse the xml of the processStatusNotifications and ping methods.

Kpn will only send these 2 messages, ping is just a way to check if a service is up, 
processStatusNotifications contains information on the status of a message and is needed to 
update the status in out db.

Numero fax del mittente:        024801371
Numero pagine:                  1
Data ricezione fax:             2013/01/18
Ora ricezione fax:              10.00.19
"""
import re
import datetime

from jmb.fax import mail2fax, models
from kpn_send import send_via_kpn, KpnManager
from kpnparse import update_status

class KpnMsg(mail2fax.MailMessage):
        
    def parse_notification(self, subject=''):
        """
        Parse the xml from kpn to get the status notification info

        :param xml: an xml 
        """
        info = {}
        self._subject = subject
        subject = self.subject
        info = {}
        m_recipient = re.search("Fax per il numero (\d+)", subject)
        if not m_recipient:
            return {}
        info['recipient_number'] = m_recipient.group(1)
        self.status = "RECEIVED"
        num = models.FaxNumber.objects.get(number=info['recipient_number'])
        info['status'] = 2
        info['device'] = num.device.all()[0]

        # Parse the body
        for line in self.notification.split('\n'):
            try:
                key, value = line.split(':')
                value = value.strip()
            except:
                continue
            if key in ('Numero fax del mittente', ):
                info['sender_number'] = value.strip()

            elif key == 'Numero pagine':
                info['pages'] = int(value.strip())

            elif key in ('Data ricezione fax',):
                date_str = value.strip()

            elif key in ('Ora ricezione fax',):
                time_str = value.strip()

        try: 
            dtime_str = "%s %s" % (date_str, time_str)
            info['date_sent'] = datetime.datetime.strptime(dtime_str, "%Y/%m/%d %H.%M.%S")
        except Exception, e:
            raise

        self.info = info
        
        return info

if __name__ == '__main__':
    xml_ping = open('ping.xml').read()
    xml_status = open('status.xml').read()

==> jmb.fax-0.6.tar.gz: jmb.fax-0.6/jmb/fax/kpn/__init__.py <==
"""
Module to parse the xml of the processStatusNotifications and ping methods.

Kpn will only send these 2 messages, ping is just a way to check if a service is up, 
processStatusNotifications contains information on the status of a message and is needed to 
update the status in out db.

Numero fax del mittente:        024801371
Numero pagine:                  1
Data ricezione fax:             2013/01/18
Ora ricezione fax:              10.00.19
"""
from __future__ import unicode_literals

import re
import datetime

from jmb.fax import mail2fax, models
from .kpn_send import send_via_kpn, KpnManager
from .kpnparse import update_status

class KpnMsg(mail2fax.MailMessage):

    def parse_notification(self, subject=''):
        """
        Parse the xml from kpn to get the status notification info

        :param xml: an xml 
        """
        info = {}
        self._subject = subject
        subject = self.subject
        info = {}
        m_recipient = re.search("Fax per il numero (\d+)", subject)
        if not m_recipient:
            return {}
        info['recipient_number'] = m_recipient.group(1)
        self.status = "RECEIVED"
        num = models.FaxNumber.objects.get(number=info['recipient_number'])
        info['status'] = 2
        info['device'] = num.device.all()[0]

        # Parse the body
        for line in self.notification.split('\n'):
            try:
                key, value = line.split(':')
                value = value.strip()
            except:
                continue
            if key in ('Numero fax del mittente', ):
                if re.match('\d+$', value.strip()):
                    info['sender_number'] = value.strip()
                else:
                    info['sender'] = value.strip()
                    info['sender_number'] = value.strip()[:16]

            elif key == 'Numero pagine':
                info['pages'] = int(value.strip())

            elif key in ('Data ricezione fax',):
                date_str = value.strip()

            elif key in ('Ora ricezione fax',):
                time_str = value.strip()

        try:
            dtime_str = "%s %s" % (date_str, time_str)
            info['date_sent'] = datetime.datetime.strptime(dtime_str, "%Y/%m/%d %H.%M.%S")
        except Exception as e:
            raise

        self.info = info

        return info

if __name__ == '__main__':
    xml_ping = open('ping.xml').read()
    xml_status = open('status.xml').read()
